@@ -7,7 +7,8 @@ from mininode import utils
 from mininode.api.base import BaseAPI
 from mininode.crypto.account import check_private_key, private_key_to_pubkey
 from mininode.crypto.sign_trx import (
-    pack_appconfig_param,
+    pack_appconfig_key_param,
+    pack_appconfig_list_param,
     pack_content_param,
     trx_decrypt,
     trx_encrypt,
@@ -297,5 +298,9 @@ class QuorumLightNodeAPI(BaseAPI):
         return params
 
     def get_appconfig_keylist(self):
-        payload = pack_appconfig_param(self.aes_key, self.group_id)
+        payload = pack_appconfig_list_param(self.aes_key, self.group_id)
+        return self._post(endpoint=f"/node/getchaindata/{self.group_id}", payload=payload)
+
+    def get_appconfig_key(self, key: str):
+        payload = pack_appconfig_key_param(self.aes_key, self.group_id, key)
         return self._post(endpoint=f"/node/getchaindata/{self.group_id}", payload=payload)
